@@ -396,7 +396,6 @@ class TestComponentCallbacks(unittest.TestCase):
         self.assertEqual(test_state.value.alias, 'delicious', 'test alias setting passthrough')
         self.assertEqual(test_state.get_name(), 'delicious', 'test name retrieval is updated')
 
-
     def test_action_callback_ordering(self):
         """
         tests that pre- and post- operational state change callbacks are executed in the correct place
@@ -525,3 +524,11 @@ class TestTemporaryCallback(unittest.TestCase):
                         self.custom_callback in state.value.pre_state_callbacks,
                         f'ensure callback was not assigned to {state}'
                     )
+
+    def test_alias_retrieval(self):
+        """tests retrieval of a ComponentState by a state alias"""
+        state = self.component.operational_states.NOT_GREAT
+        alias = 'so_so'
+        state.set_alias(alias)
+        self.assertIs(state, self.component.operational_states(alias), 'test retrieval of StateSet by alias')
+        self.assertIs(state, self.component.operational_states(state.name), 'ensure retrieval by formal name still works')
\ No newline at end of file
